Utility functions to convert between mobility and CCS data.
Usage
convertMobilityToCCS(mobility, mz, CCSParams, charge = NULL)
convertCCSToMobility(ccs, mz, CCSParams, charge = NULL)Arguments
- mobility, ccs
A
numericvector with mobility or CCS values that should be converted.- mz
A
numericvector with the m/z values that map to the input mobility or CCS values.- CCSParams
A
listwith parameters for mobility <–> CCS conversion. SeegetCCSParamsfor details and to make such parameter lists. Set toNULLto skip conversions.- charge
A
numericvector with the ion charges that map to the input mobility or CCS data. Will be recycled if necessary. IfNULLthen the charge configured inCCSParamsis used.