Components class for homologous series.
Source:R/components-nontarget.R, R/components-nontarget-set.R
componentsNT-class.RdThis class is derived from components and is used to store
results from unsupervised homolog detection with the nontarget
package.
Details
Objects from this class are generated by
generateComponentsNontarget
Methods (by generic)
plotGraph(componentsNT): Plots an interactive network graph for linked homologous series (i.e. series with (partial) overlap which could not be merged). The resulting graph can be browsed interactively and allows quick inspection of series which may be related. The graph is constructed with the igraph package and rendered with visNetwork.
Slots
homolA
listwithhomolobjects for each replicate as returned byhomol.search
Sets workflows
The componentsNTSet class is applicable for sets workflows. This class is derived from componentsNT and therefore largely follows the same user interface.
The following methods are specifically defined for sets workflows:
unsetConverts the object data for a specified set into a 'non-set' object (componentsNTUnset), which allows it to be used in 'regular' workflows. Only the components in the specified set are kept. Furthermore, the component names are restored to non-set specific names (seegenerateComponentsfor more details).
The following methods are changed or with new functionality:
plotGraphCurrently can only create graph networks from one set (specified by thesetargument).
Note that the componentsNTSet class does not have a homol slot. Instead, the setObjects
method can be used to access this data for a specific set.
References
Loos M, Singer H (2017).
“Nontargeted homologue series extraction from hyphenated high resolution mass spectrometry data.”
Journal of Cheminformatics, 9(1).
doi:10.1186/s13321-017-0197-z
.
Loos M, Gerber C, Corona F, Hollender J, Singer H (2015).
“Accelerated Isotope Fine Structure Calculation Using Pruned Transition Trees.”
Analytical Chemistry, 87(11), 5738-5744.
https://pubs.acs.org/doi/abs/10.1021/acs.analchem.5b00941.
Antonov M, Csárdi G, Horvát S, Müller K, Nepusz T, Noom D, Salmon M, Traag V, Welles BF, Zanini F (2023).
“igraph enables fast and robust network analysis across programming languages.”
arXiv preprint arXiv:2311.10260.
doi:10.48550/arXiv.2311.10260
.
Csárdi G, Nepusz T (2006).
“The igraph software package for complex network research.”
InterJournal, Complex Systems, 1695.
https://igraph.org.
Csárdi G, Nepusz T, Traag V, Horvát S, Zanini F, Noom D, Müller K, Schoch D, Salmon M (2026).
igraph: Network Analysis and Visualization in R.
doi:10.5281/zenodo.7682609
.
R package version 2.3.3, https://CRAN.R-project.org/package=igraph.