This class is derived from componentsClust and is used to store components from feature groups that
were clustered based on their MS/MS similarities.
Details
Objects from this class are generated by generateComponentsSpecClust
Note
When the object is altered (e.g. by filtering or subsetting it), methods that need the original clustered data such as plotting methods do not work anymore and stop with an error.
See also
componentsClust for other relevant methods and generateComponents