Returns an overview of scorings may be applied to rank candidate compounds.
Usage
compoundScorings(
algorithm = NULL,
database = NULL,
includeSuspectLists = TRUE,
onlyDefault = FALSE,
includeNoDB = TRUE
)Arguments
- algorithm
The algorithm:
"metfrag"or"sirius". Set toNULLto return all scorings.- database
The database for which results should be returned (e.g.
"pubchem"). Set toNULLto return all scorings.- includeSuspectLists, onlyDefault, includeNoDB
A logical specifying whether scoring terms related to suspect lists, default scoring terms and non-database specific scoring terms should be included in the output, respectively.