Returns the default adducts and their probabilities when the OpenMS algorithm is used for componentization.
Details
See the potentialAdducts argument of generateComponentsOpenMS for more details.
Returns the default adducts and their probabilities when the OpenMS algorithm is used for componentization.
See the potentialAdducts argument of generateComponentsOpenMS for more details.