Class for suspect screened feature groups.
Source:R/generics.R, R/feature_groups-screening.R, R/feature_groups-screening-set.R
featureGroupsScreening-class.RdThis class derives from featureGroups and adds suspect screening information.
Usage
screenInfo(obj)
# S4 method for class 'featureGroupsScreening'
screenInfo(obj)
# S4 method for class 'featureGroupsScreening'
show(object)
# S4 method for class 'featureGroupsScreening,ANY,ANY,missing'
x[i, j, ..., suspects = NULL, reorder = FALSE, drop = TRUE]
# S4 method for class 'featureGroupsScreening'
delete(obj, i = NULL, j = NULL, k = NULL, ...)
# S4 method for class 'featureGroupsScreening'
filter(
obj,
...,
onlyHits = NULL,
IMSMatchParams = NULL,
selectHitsBy = NULL,
selectBestFGroups = FALSE,
maxLevel = NULL,
maxFormRank = NULL,
maxCompRank = NULL,
minAnnSimForm = NULL,
minAnnSimComp = NULL,
minAnnSimBoth = NULL,
absMinFragMatches = NULL,
relMinFragMatches = NULL,
minRF = NULL,
maxLC50 = NULL,
negate = FALSE,
applyIMS = "both"
)
# S4 method for class 'featureGroupsScreeningSet'
screenInfo(obj)
# S4 method for class 'featureGroupsScreeningSet'
show(object)
# S4 method for class 'featureGroupsScreeningSet,ANY,ANY,missing'
x[i, j, ..., suspects = NULL, sets = NULL, reorder = FALSE, drop = TRUE]
# S4 method for class 'featureGroupsScreeningSet'
delete(obj, i = NULL, j = NULL, k = NULL, ...)
# S4 method for class 'featureGroupsScreeningSet'
filter(
obj,
...,
onlyHits = NULL,
IMSMatchParams = NULL,
selectHitsBy = NULL,
selectBestFGroups = FALSE,
maxLevel = NULL,
maxFormRank = NULL,
maxCompRank = NULL,
minAnnSimForm = NULL,
minAnnSimComp = NULL,
minAnnSimBoth = NULL,
absMinFragMatches = NULL,
relMinFragMatches = NULL,
minRF = NULL,
maxLC50 = NULL,
negate = FALSE,
applyIMS = "both"
)
# S4 method for class 'featureGroupsScreeningSet'
unset(obj, set)Arguments
- obj, object, x
The
featureGroupsScreeningobject.- i, j, reorder
See
featureGroups.- ...
Further arguments passed to the base method.
- suspects
An optional
charactervector with suspect names. If specified, onlyfeatureGroupswill be kept that are assigned to these suspects.- drop
Ignored.
- k
The
kargument is used to delete screening results (instead of features) and should be:a
charactervector with suspect names that should be removeda
functionthat is called with the screening info table and should return alogicalvector for each suspect row to be removedNAto remove all screening results, which is especially useful when paired with thejargument, i.e. to remove all screening results for a particular set of feature groups.NULLto not touch screening results and only perform deletion as thefeatureGroupsmethod.
Setting both
iandkis currently not supported.- onlyHits
If
negate=FALSEandonlyHits=TRUEthen all feature groups without suspect hits will be removed. Otherwise nothing will be done.negate=TRUEthenonlyHits=TRUEwill select feature groups without suspect hits,onlyHits=FALSEwill only retain feature groups with suspect matches and this filter is ignored ifonlyHits=NULL.
- IMSMatchParams
(IMS workflow) A
listwith parameters to be used for matching IMS data. SeegetIMSMatchParamsfor details and how to make such a parameter list.- selectHitsBy
Should be
"intensity"or"level". For cases where the same suspect is matched to multiple feature groups, only the suspect to the feature group with highest mean intensity (selectHitsBy="intensity") or best identification level (selectHitsBy="level") is kept. In case of ties only the first hit is kept. Set toNULLto ignore this filter. Ifnegate=TRUEthen only those hits with lowest mean intensity/poorest identification level are kept.- selectBestFGroups
If
TRUEthen for any cases where a single feature group is matched to several suspects only the suspect assigned to the feature group with best identification score is kept. In case of ties only the first is kept.- maxLevel, maxFormRank, maxCompRank, minAnnSimForm, minAnnSimComp, minAnnSimBoth
Filter suspects by maximum identification level (e.g.
"3a"), formula/compound rank or with minimum formula/compound/combined annotation similarity. Set toNULLto ignore.- absMinFragMatches, relMinFragMatches
Only retain suspects with this minimum number MS/MS matches with the fragments specified in the suspect list (i.e.
fragments_mz/fragments_formula).relMinFragMatchessets the minimum that is relative (0-1) to the maximum number of MS/MS fragments specified in thefragments_*columns of the suspect list. Set toNULLto ignore.- minRF
Filter suspect hits by the given minimum predicted response factor (as calculated by
predictRespFactors). Set toNULLto ignore.- maxLC50
Filter suspect hits by the given maximum toxicity (LC50) (as calculated by
predictTox). Set toNULLto ignore.- negate
If set to
TRUEthen filtering operations are performed in opposite manner.- applyIMS
(IMS workflow) whether the filters are only applied to IMS precursors (
applyIMS=FALSE), only to IMS features (applyIMS=TRUE) or to both (applyIMS="both"). Other feature groups will always be kept. Thenegateoption does not affectapplyIMS.- sets
(sets workflow) A
characterwith name(s) of the sets to keep (or remove ifnegate=TRUE).- set
(sets workflow) The name of the set.
Value
delete returns the object for which the specified data was removed.
filter returns a filtered featureGroupsScreening object.
Methods (by generic)
screenInfo(featureGroupsScreening): Returns a table with screening information (seescreenInfoslot).show(featureGroupsScreening): Shows summary information for this object.x[i: Subset on analyses, feature groups and/or suspects.delete(featureGroupsScreening): Completely deletes specified feature groups or screening results.filter(featureGroupsScreening): Performs rule based filtering. This method builds on the comprehensive filter functionality from the basefilter,featureGroups-method. It adds several filters to select e.g. the best ranked suspects or those with a minimum estimated identification level. NOTE: most filters only affect suspect hits, not feature groups. SetonlyHits=TRUEto subsequently remove any feature groups that lost any suspect matches due to these filter steps.
Slots
screenInfoA (
data.table) with results from suspect screening. This table will be amended with ID confidence data whenestimateIDConfidenceis run.MS2QuantMetaMetadata from MS2Quant filled in by
predictRespFactors.(sets workflow) A named
listwith the metadata stored for each set.
Note
filter removes suspect hits with NA values when any of the filters related to minimum or maximum
values are applied (unless negate=TRUE).
Sets workflows
The featureGroupsScreeningSet class is applicable for sets workflows. This class is derived from featureGroupsScreening and therefore largely follows the same user interface.
The following methods are specifically defined for sets workflows:
unsetConverts the object data for a specified set into a 'non-set' object (featureGroupsScreeningUnset), which allows it to be used in 'regular' workflows. Only the screening results present in the specified set are kept.
The following methods are changed or with new functionality:
estimateIDConfidenceSee theSets workflowssection in the documentation forestimateIDConfidence.filterAll filters related to estimated identification levels and formula/compound rankings are applied to the overall set data (see above). All others are applied to set specific data: in this case candidates are only removed if none of the set data confirms to the filter.
This class derives also from featureGroupsSet. Please see its documentation for more relevant details
with sets workflows.
Note that the formRank and compRank columns are not updated when the data is subset.