Uses the enviPickwrap function from the enviPick R package to extract features.
Arguments
- analysisInfo
A
data.frame(ordata.table) with Analysis information.- ...
Further parameters passed to
enviPickwrap.- parallel
If set to
TRUEthen code is executed in parallel through the future package. Please see the parallelization section in the handbook for more details.- verbose
If set to
FALSEthen no text output is shown.
Value
An object of a class which is derived from features.
Details
This function uses enviPick to automatically find features. This function is called when calling findFeatures with
algorithm="envipick".
The input MS data files need to be centroided. The convertMSFiles function can be used
to centroid data.
See also
findFeatures for more details and other algorithms.