uses the FeatureFinderMetabo TOPP tool (see http://www.openms.de) to find features.
Usage
findFeaturesOpenMS(
analysisInfo,
noiseThrInt = 1000,
chromSNR = 3,
chromFWHM = 5,
mzPPM = defaultLim("mz", "medium_rel"),
reEstimateMTSD = TRUE,
traceTermCriterion = "sample_rate",
traceTermOutliers = 5,
minSampleRate = 0.5,
minTraceLength = 3,
maxTraceLength = -1,
widthFiltering = "fixed",
minFWHM = 1,
maxFWHM = 30,
traceSNRFiltering = FALSE,
localRTRange = 10,
localMZRange = 6.5,
isotopeFilteringModel = "metabolites (5% RMS)",
MZScoring13C = FALSE,
useSmoothedInts = TRUE,
extraOpts = NULL,
useFFMIntensities = FALSE,
verbose = TRUE
)Arguments
- analysisInfo
A
data.frame(ordata.table) with Analysis information.- noiseThrInt
Noise intensity threshold. Sets
algorithm:common:noise_threshold_intoption.- chromSNR
Minimum S/N of a mass trace. Sets
algorithm:common:chrom_peak_snroption.- chromFWHM
Expected chromatographic peak width (in seconds). Sets
algorithm:common:chrom_fwhmoption.- mzPPM
Allowed mass deviation (ppm) for trace detection. Sets
algorithm:mtd:mass_error_ppm.- reEstimateMTSD
If
TRUEthen enables dynamic re-estimation of m/z variance during mass trace collection stage. Setsalgorithm:mtd:reestimate_mt_sd.- traceTermCriterion, traceTermOutliers, minSampleRate
Termination criterion for the extension of mass traces. See FeatureFinderMetabo. Sets the
algorithm:mtd:trace_termination_criterion,algorithm:mtd:trace_termination_outliersandalgorithm:mtd:min_sample_rateoptions, respectively.- minTraceLength, maxTraceLength
Minimum/Maximum length of mass trace (seconds). Set negative value for maxlength to disable maximum. Sets
algorithm:mtd:min_trace_lengthandalgorithm:mtd:min_trace_length, respectively.- widthFiltering, minFWHM, maxFWHM
Enable filtering of unlikely peak widths. See FeatureFinderMetabo. Sets
algorithm:epd:width_filtering,algorithm:epd:min_fwhmandalgorithm:epd:max_fwhm, respectively.- traceSNRFiltering
If
TRUEthen apply post-filtering by signal-to-noise ratio after smoothing. Sets thealgorithm:epd:masstrace_snr_filteringoption.- localRTRange, localMZRange
Retention/MZ range where to look for coeluting/isotopic mass traces. Sets the
algorithm:ffm:local_rt_rangeandalgorithm:ffm:local_mz_rangeoptions, respectively.- isotopeFilteringModel
Remove/score candidate assemblies based on isotope intensities. See FeatureFinderMetabo. Sets the
algorithm:ffm:isotope_filtering_modeloption.- MZScoring13C
Use the 13C isotope as the expected shift for isotope mass traces. See FeatureFinderMetabo. Sets
algorithm:ffm:mz_scoring_13C.- useSmoothedInts
If
TRUEthen use LOWESS intensities instead of raw intensities. Sets thealgorithm:ffm:use_smoothed_intensitiesoption.- extraOpts
Named
listcontaining extra options that will be passed toFeatureFinderMetabo. Any options specified here will override any of the above. Example:extraOpts=list("-algorithm:common:noise_threshold_int"=1000)(corresponds to settingnoiseThrInt=1000). Set toNULLto ignore.- useFFMIntensities
If
TRUEthen peak intensities are directly loaded fromFeatureFinderMetabooutput. Otherwise, intensities are loaded afterwards from the inputmzMLfiles, which is potentially much slower, especially with many analyses files. However,useFFMIntensities=TRUEis still somewhat experimental, may be less accurate and requires a recent version ofOpenMS(>=2.7).- verbose
If set to
FALSEthen no text output is shown.
Value
An object of a class which is derived from features.
Details
This function uses OpenMS to automatically find features. This function is called when calling findFeatures with
algorithm="openms".
This functionality has been tested with OpenMS version >= 2.0. Please make sure it is installed and
configured, e.g. by installing patRoonExt or configuring the path of the binaries with
the patRoon.path.OpenMS option or the system PATH variable.
The file format of analyses must be mzML.
The input MS data files need to be centroided. The convertMSFiles function can be used
to centroid data.
Parallelization
findFeaturesOpenMS with useFFMIntensities=FALSE uses multiprocessing to parallelize
computations. Please see the parallelization section in the handbook for
more details and patRoon options for configuration
options.
Note that for caching purposes, the analyses files must always exist on the local host computer, even if it is not participating in computations.
Use of raw HRMS data
The raw data interface of patRoon is used by findFeaturesOpenMS with useFFMIntensities=FALSE to
process HRMS (or IMS-HRMS) data. Please see its documentation for more information on the supported
formats and available configuration options.
References
Rost HL, Sachsenberg T, Aiche S, Bielow C, Weisser H, Aicheler F, Andreotti S, Ehrlich H, Gutenbrunner P, Kenar E, Liang X, Nahnsen S, Nilse L, Pfeuffer J, Rosenberger G, Rurik M, Schmitt U, Veit J, Walzer M, Wojnar D, Wolski WE, Schilling O, Choudhary JS, Malmstrom L, Aebersold R, Reinert K, Kohlbacher O (2016).
“OpenMS: a flexible open-source software platform for mass spectrometry data analysis.”
Nature Methods, 13(9), 741–748.
doi:10.1038/nmeth.3959
.
pugixml (via
Rcpp) is used to process OpenMS XML output.
Eddelbuettel D (2013).
Seamless R and C++ Integration with Rcpp.
Springer, New York.
doi:10.1007/978-1-4614-6868-4
.
ISBN 978-1-4614-6867-7.
Eddelbuettel D, Balamuta J (2018).
“Extending R with C++: A Brief Introduction to Rcpp.”
The American Statistician, 72(1), 28-36.
doi:10.1080/00031305.2017.1375990
.
Eddelbuettel D, François R (2011).
“Rcpp: Seamless R and C++ Integration.”
Journal of Statistical Software, 40(8), 1–18.
doi:10.18637/jss.v040.i08
.
Eddelbuettel D, Francois R, Allaire J, Ushey K, Kou Q, Russell N, Ucar I, Bates D, Chambers J (2026).
Rcpp: Seamless R and C++ Integration.
R package version 1.1.2, https://www.rcpp.org.
See also
findFeatures for more details and other algorithms.