Generate peak lists with Bruker DataAnalysis from bruker features (deprecated)
Source:R/generics.R, R/deprecated-mspeaklists-bruker.R
generateMSPeakListsDAFMF.RdUses 'compounds' that were generated by the Find Molecular Features (FMF) algorithm of Bruker DataAnalysis to extract
MS peak lists. This function is now deprecated, please use generateMSPeakLists instead.
Usage
generateMSPeakListsDAFMF(fGroups, ...)
# S4 method for class 'featureGroups'
generateMSPeakListsDAFMF(
fGroups,
minMSIntensity = 500,
minMSMSIntensity = 500,
close = TRUE,
save = close,
avgFGroupParams = getDefAvgPListParams()
)
# S4 method for class 'featureGroupsSet'
generateMSPeakListsDAFMF(fGroups, ...)Arguments
- fGroups
The
featureGroupsobject for which MS peak lists should be generated.- ...
(sets workflow) Further arguments passed to the non-sets workflow method.
- minMSIntensity, minMSMSIntensity
Minimum intensity for peak lists obtained with DataAnalysis. Highly recommended to set >0 as DA tends to report many very low intensity peaks.
- close, save
If
TRUEthen Bruker files are closed and saved after processing with DataAnalysis, respectively. Settingclose=TRUEprevents that many analyses might be opened simultaneously in DataAnalysis, which otherwise may use excessive memory or become slow. By defaultsaveisTRUEwhencloseisTRUE, which is likely what you want as otherwise any processed data is lost.- avgFGroupParams
A
listwith parameters used for averaging of peak lists for feature groups. SeegetDefAvgPListParamsfor more details.
Value
An MSPeakLists object.
Details
This function is similar to generateMSPeakListsDA, but uses 'compounds' that were generated by
the Find Molecular Features (FMF) algorithm to extract MS peak lists. This is generally much faster , however, it
only works when features were obtained with the findFeaturesBruker function. Since all MS spectra are
generated in advance by Bruker DataAnalysis, only few parameters exist to customize its operation.