Parameters that define a range of mobility or CCS values.
Details
The following parameters are used to define an IMS range:
paramShould be"mobility"or"CCS"to specify a mobility or CCS range, respectively.lower,upperThe lower and upper range.mzRelativeSet toTRUEto specify an IMS range that is normalized by m/z.
These parameters are passed as a named list as the IMSRangeParams argument to functions.
The getIMSRangeParams function generates such parameter list with defaults.