Returns the supported file formats of MS files in patRoon.
Arguments
- fileType
The type of file for which formats should be returned (see
getMSFileTypes). IfNULLthen all file formats are returned.
Returns the supported file formats of MS files in patRoon.
The type of file for which formats should be returned (see getMSFileTypes). If
NULL then all file formats are returned.