R/feature_groups-xcms3.R
importFeatureGroupsXCMS3.RdImports feature groups from XCMS (new interface)
importFeatureGroupsXCMS3(input, analysisInfo)An XCMSnExp object.
A data.frame (or data.table) with Analysis
information.
An object of a class which is derived from featureGroups.
This function imports data from XCMS3. This function is called when calling importFeatureGroups with
type="xcms3".
Benton HP, Want EJ, Ebbels TMD (2010).
“Correction of mass calibration gaps in liquid chromatography-mass spectrometry metabolomics data.”
BIOINFORMATICS, 26, 2488.
Louail P, Brunius C, Garcia-Aloy M, Kumler W, Storz N, Stanstrup J, Treutler H, Vangeenderhuysen P, Witting M, Neumann S, Rainer J (2025).
“xcms in Peak Form: Now Anchoring a Complete Metabolomics Data Preprocessing and Analysis Software Ecosystem.”
Analytical Chemistry.
doi:10.1021/acs.analchem.5c04338
.
https://doi.org/10.1021/acs.analchem.5c04338.
Smith, C.A., Want, E.J., O'Maille, G., Abagyan,R., Siuzdak, G. (2006).
“XCMS: Processing mass spectrometry data for metabolite profiling using nonlinear peak alignment, matching and identification.”
Analytical Chemistry, 78, 779–787.
Tautenhahn R, Boettcher C, Neumann S (2008).
“Highly sensitive feature detection for high resolution LC/MS.”
BMC Bioinformatics, 9, 504.
importFeatureGroups for more details and other algorithms.