Imports features from a project generated by the enviMass package.
Arguments
- input
The path of the enviMass project.
- analysisInfo
A
data.frame(ordata.table) with Analysis information.
Value
An object of a class which is derived from features.
Details
This function imports data from enviMass. This function is called when calling importFeatures with
type="envimass".
See also
importFeatures for more details and other algorithms.