Automatically installs the C3SDB Python package
Arguments
- envname
The name of the virtual
Pythonenvironment to installC3SDBinto. Passed to reticulate::py_install. Set toNULLto not set any virtualPythonenvironment.- clearEnv
Set to
TRUEto remove the virtual environment if it already exists (using reticulate::virtualenv_remove). Ignored ifenvnameisNULL.- ...
Further arguments passed to
reticulate::py_install.
Details
This function uses reticulate to install the C3SDB
Python package in a virtual environment.
References
Ross DH, Cho JH, Xu L (2020). “Breaking Down Structural Diversity for Comprehensive Prediction of Ion-Neutral Collision Cross Sections.” Analytical Chemistry, 92(6), 4548–4557. ISSN 1520-6882. doi:10.1021/acs.analchem.9b05772 . http://dx.doi.org/10.1021/acs.analchem.9b05772.