Please do not use these functions anymore since they may be removed in the future.
Details
reportHTML performs HTML reporting, please use
report instead.
Please use estimateIDConfidence instead.
Please do not use these functions anymore since they may be removed in the future.
reportHTML performs HTML reporting, please use
report instead.
Please use estimateIDConfidence instead.