Base transformation products (TP) class with formula information
Source:R/TP-formula.R, R/TP-library_formula.R
transformationProductsFormula-class.RdHolds information for all TPs for a set of parents, including chemical formulae.
Usage
# S4 method for class 'transformationProductsFormula'
plotGraph(
obj,
which,
components = NULL,
prune = TRUE,
onlyCompletePaths = FALSE,
width = NULL,
height = NULL
)Arguments
- obj
transformationProductsFormuladerived object to be accessed- which
Either a
characterorintegervector with one or more names/indices of the parents to plot.- components
If specified (i.e. not
NULL), acomponentsTPsobject that is used for matching the graph with screening results. The TPs that were found will be marked. See also thepruneandonlyCompletePathsarguments.- prune
If
TRUEandcomponentsis set, then pathways without any detected TPs are not shown (pruned). See also theonlyCompletePathsandcomponentsarguments.- onlyCompletePaths
If
TRUEandcomponentsis set, then only pathways are shown for which all TPs were detected. See also thepruneandcomponentsarguments.- width, height
Passed to
visNetwork.
Details
This (virtual) class is derived from the transformationProducts base class, please see its
documentation for more details. Objects from this class are returned by TP generators. More
specifically, algorithms that works with chemical formulae (e.g. library_formula), uses this class to
store their results. The methods defined for this class extend the functionality for the base
transformationProducts class.
Methods (by generic)
plotGraph(transformationProductsFormula): Plots an interactive hierarchy graph of the transformation products. The resulting graph can be browsed interactively and allows exploration of the different TP formation pathways. Furthermore, results from TP componentization can be used to match the hierarchy with screening results. The graph is rendered with visNetwork.
See also
The base class transformationProducts for more relevant methods and generateTPs