Components based on clustered intensity profiles.
Source:R/generics.R, R/components-intclust.R
componentsIntClust-class.RdThis class is derived from componentsClust and is used to store hierarchical clustering information
from intensity profiles of feature groups.
Arguments
- obj
A
componentsIntClustobject.- ...
Further options passed to
heatmap.2/heatmaply(plotHeatMap).- interactive
If
TRUEan interactive heatmap will be drawn (withheatmaply).- col
The colour used for plotting. Set to
NULLfor automatic colours.- margins, cexCol
Passed to
heatmap.2- index
Numeric component/cluster index or component name.
- pch, type, lty
Passed to
lines.- plotArgs, linesArgs
A
listwith further arguments passed toplotandlines, respectively.
Details
Objects from this class are generated by generateComponentsIntClust
Methods (by generic)
plotHeatMap(componentsIntClust): draws a heatmap using theheatmap.2orheatmaplyfunction.plotInt(componentsIntClust): makes a plot for all (normalized) intensity profiles of the feature groups within a given cluster.
Slots
clustermNumeric matrix with normalized feature group intensities that was used for clustering.
Note
When the object is altered (e.g. by filtering or subsetting it), methods that need the original clustered data such as plotting methods do not work anymore and stop with an error.
See also
componentsClust for other relevant methods and generateComponents