Components class for network-based componentization.
Source:R/components-net.R, R/components-net-set.R
componentsNet-class.RdThis class is derived from components and is used to store results from network-based componentization.
Details
Objects from this class are generated by generateComponentsNet.
Methods (by generic)
plotGraph(componentsNet): Plots an interactive network graph for the feature components of an analysis.
Slots
featureComponentsA
listwith feature components for each analysis.featureGraphsA
listwith feature network graphs (igraph) for each analysis.annotationObjectsA
listwith annotation objects for each component (fromnontargetorInterpretMSSpectrum).
Sets workflows
The componentsNetSet class is applicable for sets workflows. This class is derived from componentsNet and therefore largely follows the same user interface.
The following methods are specifically defined for sets workflows:
unsetConverts the object data for a specified set into a 'non-set' object (componentsNetUnset), which allows it to be used in 'regular' workflows. Only the components in the specified set are kept. Furthermore, the component names are restored to non-set specific names (seegenerateComponentsfor more details).
The following methods are changed or with new functionality:
plotGraphCurrently can only create graph networks from one set (specified by thesetargument).
Note that the componentsNetSet class does not have featureComponents and featureGraphs slots.
Instead, the setObjects method can be used to access this data for a specific set.
References
Antonov M, Csárdi G, Horvát S, Müller K, Nepusz T, Noom D, Salmon M, Traag V, Welles BF, Zanini F (2023).
“igraph enables fast and robust network analysis across programming languages.”
arXiv preprint arXiv:2311.10260.
doi:10.48550/arXiv.2311.10260
.
Csárdi G, Nepusz T (2006).
“The igraph software package for complex network research.”
InterJournal, Complex Systems, 1695.
https://igraph.org.
Csárdi G, Nepusz T, Traag V, Horvát S, Zanini F, Noom D, Müller K, Schoch D, Salmon M (2026).
igraph: Network Analysis and Visualization in R.
doi:10.5281/zenodo.7682609
.
R package version 2.3.3, https://CRAN.R-project.org/package=igraph.