Functions to define and work with chromatographic peak quality metrics used for feature and feature group quality calculations.
featureQualities(qualities = NULL)
featureGroupQualities(qualities = NULL)
featureQualityNames(feat = TRUE, group = TRUE, scores = FALSE, totScore = TRUE)A character vector specifying which qualities to return. If NULL, returns all available
quality definitions.
If TRUE then names specific to features are returned.
If TRUE then names specific to groups are returned.
If TRUE the score names are returned, otherwise the quality names.
If TRUE (and scores=TRUE) then the name of the total score is included.
For featureQualities and featureGroupQualities: A named list containing quality definitions.
Each element contains:
func: The MetaClean function to calculate the quality metric
HQ: "HV" (high values good) or "LV" (low values good)
range: Expected range of values (may be Inf for unbounded ranges)
For featureQualityNames: A character vector with quality and/or score names.
These functions provide access to quality metrics that are used to assess the quality of detected features and
feature groups by the calculatePeakQualities function. The quality metrics are calculated using the
MetaClean package and are useful for filtering out low-quality features before further analysis.
The featureQualities function defines quality metrics that are calculated for
individual features. The following quality metrics are available:
ApexBoundaryRatio - Ratio between apex and boundary intensities
FWHM2Base - Full width at half maximum to base ratio
Jaggedness - Measure of peak smoothness
Modality - Measure of peak multiplicity
Symmetry - Measure of peak symmetry (range: -1 to 1)
GaussianSimilarity - Similarity to Gaussian distribution
Sharpness - Measure of peak sharpness
TPASR - Triangle peak area similarity ratio
ZigZag - Zig-zag index measure
The featureGroupQualities function defines quality metrics that are
calculated for feature groups across multiple analyses. The following quality metrics are available:
ElutionShift - Measure of retention time consistency across analyses
RetentionTimeCorrelation - Correlation of retention times across analyses
Chetnik K, Petrick L, Pandey G (2020). “MetaClean: a machine learning-based classifier for reduced false positive peak detection in untargeted LC-MS metabolomics data.” Metabolomics, 16(11). doi:10.1007/s11306-020-01738-3 .