Uses the enviPickwrap function from the enviPick R package to extract features.
findFeaturesEnviPick(analysisInfo, ..., parallel = TRUE, verbose = TRUE)A data.frame (or data.table) with Analysis
information.
Further parameters passed to enviPickwrap.
If set to TRUE then code is executed in parallel through the future package. Please
see the parallelization section in the handbook for more details.
If set to FALSE then no text output is shown.
An object of a class which is derived from features.
This function uses enviPick to automatically find features. This function is called when calling findFeatures with
algorithm="envipick".
The input MS data files need to be centroided. The convertMSFiles function can be used
to centroid data.
The analysis files must be in the mzXML format.
findFeatures for more details and other algorithms.