R/generics.R, R/components-specclust.R
generateComponentsSpecClust.RdGenerates components based on MS/MS similarity between feature groups.
generateComponentsSpecClust(fGroups, ...)
# S4 method for class 'featureGroups'
generateComponentsSpecClust(
fGroups,
MSPeakLists,
method = "complete",
specSimParams = getDefSpecSimParams(),
maxTreeHeight = 1,
deepSplit = TRUE,
minModuleSize = 1,
IMS = "maybe"
)featureGroups object for which components should be generated.
Any parameters to be passed to the selected component generation algorithm.
The MSPeakLists object for the given feature groups that should be used for MS
spectral similarity calculations.
Clustering method that should be applied (passed to
fastcluster::hclust).
A named list with parameters that influence the calculation of MS spectra similarities.
See the spectral similarity parameters documentation for more details.
Arguments used by
cutreeDynamicTree.
(IMS workflow) Specifies which feature groups are considered for componentization in IMS workflows. The following options are valid:
"both": Selects IMS and non-IMS features.
"maybe": Selects non-IMS features and IMS features without assigned IMS precursor.
FALSE: Selects only non-IMS features.
TRUE: Selects only IMS features.
The components are stored in objects derived from componentsSpecClust.
This function uses hierarchical clustering of MS/MS spectra to generate components. This function is called when calling generateComponents with
algorithm="specclust".
The similarities are converted to a distance matrix and used as input for hierarchical clustering, and the
resulting dendrogram is automatically cut with cutreeDynamicTree. The clustering is performed with
fastcluster::hclust.
In IMS workflows with post mobility assignment (see
assignMobilities) it may be necessary to call expandForIMS when
componentization was performed prior to mobility assignments, see its documentation for more details.
If mobilities were already assigned prior to componentization, then the IMS argument selects which feature
groups are subjected to componentization. Data for IMS feature groups that were not considered (i.e.
when IMS is FALSE or "maybe"), will be expanded similarly as is done by
expandForIMS.
In a sets workflow the spectral similarities for each set are
combined as is described for the spectrumSimilarity method
for sets workflows.
Müllner D (2013). “fastcluster: Fast Hierarchical, Agglomerative Clustering Routines for R and Python.” Journal of Statistical Software, 53(9), 1–18. doi:10.18637/jss.v053.i09 .
generateComponents for more details and other algorithms.