Automatically obtains transformation products from a library.
generateTPsLibrary(
parents = NULL,
TPLibrary = NULL,
generations = 1,
skipInvalid = TRUE,
prefCalcChemProps = TRUE,
neutralChemProps = FALSE,
neutralizeTPs = FALSE,
matchParentsBy = "InChIKey",
matchGenerationsBy = "InChIKey",
TPStructParams = getDefTPStructParams()
)The parents for which transformation products should be obtained. This can be
a suspect list (see suspect screening for more information)
the output of screenSuspects in which case the suspects hits are used as parents
a compounds object in which case all candidates are used
parents
NULL in which case all parents from the library are used.
The parents need to have SMILES or InChI information available.
If NULL, a default PubChem based library is
used. Otherwise, TPLibrary should be a data.frame. See the details below.
An integer that specifies the number of transformation generations. TPs for subsequent
iterations obtained by repeating the library search where the TPs from the previous generation are considered
parents.
If set to TRUE then the parents will be skipped (with a warning) for which insufficient
information (e.g. SMILES) is available.
If TRUE then calculated chemical properties such as the formula and
InChIKey are preferred over what is already present in the parent suspect list. For efficiency reasons it is
recommended to set this to TRUE. See the Validating and calculating chemical properties section for
more details.
If TRUE then the neutral form of the molecule is considered to calculate
SMILES, formulae etc. Enabling this may improve feature matching when considering common adducts
(e.g. [M+H]+, [M-H]-). See the Validating and calculating chemical properties section
for more details.
If TRUE then all resulting TP structure information is
neutralized. This argument has a similar meaning as neutralChemProps. This is defaulted to TRUE for
prediction algorithms, as these may output charged molecules. NOTE: if neutralization results in
duplicate TPs, i.e. when the neutral form of the TP was also generated by the algorithm, then the
neutralized TP will be removed.
A character that specifies how the input parents are matched with the data from the TP
library. Valid options are: "InChIKey", "InChIKey1", "InChI", "SMILES",
"formula", "name". If the parent from the TP library is matched with multiple input parents then only
the first is considered.
Similar to matchParentsBy, but specifies how parents/TPs are matched when
generations>1.
Parameters that influence the calculation of structural properties. See
getDefTPStructParams.
The TPs are stored in an object derived from the transformationProductsStructure class.
This function uses a library to obtain transformation products. This function is called when calling generateTPs with
algorithm="library".
By default, a library is used that is based on data from PubChem. However, it also possible to use your own library.
When the parents argument is a compounds object, the
candidate library identifier is used in case the candidate has no defined compoundName.
The TPLibrary argument is used to specify a custom TP library. This should be a
data.frame where each row specifies a TP for a parent, with the following columns:
parent_name and TP_name: The name of the parent/TP.
parent_SMILES and TP_SMILES The SMILES of the parent/TP structure.
retDir The expected retention order direction. (optional)
For generateTPsLibrary: If not specified or forceCalcRetDir=TRUE from
TPStructParams, then the log P values below may be used to calculate
retention order directions.
parent_LogP and TP_LogP The log P values for the parent/TP. (optional)
logPDiff The difference between parent and TP Log P values. Ignored if both
parent_LogP and TP_LogP are specified. (optional)
Other columns are allowed, and will be included in the final object. Multiple TPs for a single parent are specified
by repeating the value within parent_ columns.
Chemical properties such as SMILES, InChIKey and formulae in the parent suspect list are automatically validated and calculated if missing/invalid.
The internal validation/calculation process performs the following steps:
Validation of SMILES, InChI, InChIKey and formula data (if present). Invalid
entries will be set to NA.
If neutralChemProps=TRUE then chemical data (SMILES, formulae etc.) is neutralized by
(de-)protonation (using the –neutralized option of OpenBabel). An additional column
molNeutralized is added to mark those molecules that were neutralized. Note that neutralization requires
either SMILES or InChI data to be available.
The SMILES and InChI data are used to calculate missing or invalid SMILES,
InChI, InChIKey and formula data. If prefCalcChemProps=TRUE then existing
InChIKey and formula data is overwritten by calculated values whenever possible.
The chemical formulae which were not calculated are verified and normalized. This process may be time
consuming, and is potentially largely avoided by setting prefCalcChemProps=TRUE.
Neutral masses are calculated for missing values (prefCalcChemProps=FALSE) or whenever possible
(prefCalcChemProps=TRUE).
Note that calculation of formulae for molecules that are isotopically labelled is currently only supported for deuterium (2H) elements.
This functionality relies heavily on OpenBabel, please make sure it is installed.
OBoyle NM, Banck M, James CA, Morley C, Vandermeersch T, Hutchison GR (2011). “Open Babel: An open chemical toolbox.” Journal of Cheminformatics, 3(1). doi:10.1186/1758-2946-3-33 .
generateTPs for more details and other algorithms.