Create parameter lists for averaging MS peak list data.
Usage
getDefAvgPListParams(..., IMS = getLimIMS())Arguments
- ...
Optional named arguments that override defaults.
- IMS
A
characterthat specifies for which IMS instrument defaults are returned. Should be"bruker"or"agilent". Defaults to what is specified in limits.
Details
The parameters set used for averaging peak lists are set by the avgFeatParams and avgFGroupParams
arguments to generateMSPeakLists and its related algorithm specific functions. The parameters are
specified as a named list with the following values:
method,clusterMzWindowThe cluster method and window (see clustering parameters) used to average mass spectra.clusterMzWindowis defaulted asdefaultLim("mz", "medium")(see limits).topMostOnly retain this maximum number of MS peaks when generating averaged spectra. Lowering this number may exclude more irrelevant (noisy) MS peaks and decrease processing time, whereas higher values may avoid excluding lower intense MS peaks that may still be of interest.minIntensityPreMS peaks with intensities below this value will be removed (applied prior to selection bytopMostand averaging).minIntensityPostMS peaks with intensities below this value will be removed (after averaging).minIntensityIMSMS peaks in spectra of raw IMS frames with intensities below this value will be removed (applied prior to any other treatment steps).absMinAbundance,relMinAbundanceMinimum absolute/relative abundance of an MS peak across the spectra that are averaged. IfabsMinAbundanceexceeds the number of spectra then the threshold is automatically lowered to the number of spectra.maxRelCumIntensityThe maximum relative cumulative intensity of a peak, calculated in descending order (most intense peaks first). Set to 1 to disable.smoothWindowIMS,halfWindowIMS,maxGapIMSParameters used for centroiding m/z peaks from IMS-HRMS data. SeeCentroiding IMS datafor more details.withPrecursorMSFor MS data only: ignore any spectra that do not contain the precursor peak.For IMS data this excludes MS spectra within an IMS frame that do not contain the precursor peak, typically due to mobility separation. Hence, setting this option performs some crude cleanup of MS spectra, even for features for which no mobilities were assigned (e.g. non-IMS workflows).
pruneMissingPrecursorMSFor MS data only: ifTRUEthen peak lists without a precursor peak are removed. Note that even when this is set toFALSE, functionality that relies on MS (not MS/MS) peak lists (e.g. formulae calculation) will still skip calculation if a precursor is not found.retainPrecursorMSMSFor MS/MS data only: ifTRUEthen always retain the precursor mass peak even if is not amongst thetopMostpeaks. Note that MS precursor mass peaks are always kept. Furthermore, note that precursor peaks in both MS and MS/MS data may still be removed by intensity thresholds (this is unlike thefiltermethod function).
The getDefAvgPListParams function can be used to generate a default parameter list. The defaults are (with
IMS="bruker"):
list(
method = "distance_mean",
clusterMzWindow = 0.005,
topMost = 50,
minIntensityPre = 500,
minIntensityPost = 500,
minIntensityIMS = 25,
absMinAbundance = 0,
relMinAbundance = 0,
maxRelCumIntensity = 1,
smoothWindowIMS = 0,
halfWindowIMS = 2,
maxGapIMS = 0.005,
withPrecursorMS = TRUE,
pruneMissingPrecursorMS = TRUE,
retainPrecursorMSMS = TRUE
)Centroiding IMS data
With IMS-HRMS data the m/z peaks are often not or partially centroided. The following steps are performed to centroid the data:
Sum up mass spectra within an IMS frame. If the feature has mobility data, only spectra within its mobility boundaries are considered.
Use point-distance clustering (see clustering parameters) with a window defined by
maxGapIMSto find related mass signals. This is primarily meant for non-continuous data, e.g. due to intensity thresholding. ThemaxGapIMSparameter should be set to a value that represents the maximum expected distance between two m/z datapoints. For some instruments, such as Agilent IMS-QTOF, this value may be higher than expected. For that reason, ifIMS="agilent"then the default is set to0.01.Smooth the intensity data using a centered moving average with window size
smoothWindowIMS(set to zero to disable smoothing).Find local maxima within sliding window with +/-
halfWindowIMSpoints and eliminate non-centroids. This algorithm is based on theC_localMaximafunction from MALDIquant.
References
Gibb S, Strimmer K (2012). “MALDIquant: a versatile R package for the analysis of mass spectrometry data.” Bioinformatics, 28(17), 2270–2271. doi:10.1093/bioinformatics/bts447 .