Parameters to handle TP data with structural information
Source:R/utils-exported.R
getDefTPStructParams.RdParameters used by generateTPs with algorithms that use structural information.
Details
The following parameters can be configured:
calcLogPAcharacterspecifying whetherlog Pvalues should be calculated withrcdk::get.xlogp(calcLogP="rcdk"), OpenBabel (calcLogP="obabel") or not at all (calcLogP="none"). Thelog Pare values of parents and TPs are used for retention order calculation.forceCalcLogPForce calculation ofLog Pvalues, even if already provided by the TP generation algorithm. This is primarily useful to obtain log P values that were consistently calculated with the same algorithm, as some algorithms may only partially output these values (e.g. not for parents).forceCalcRetDirForce calculation of retention order directions, even if already provided by the TP generation algorithm. This is primarily intended for re-calculation of library TP data, which may have been calculated with different log P values.minLogPDiffThe minimum difference inlog Pvalues between a parent and its TPs to be considered eluting differently. This is used for retention order calculation.calcSimsIf set toTRUEthen structural similarities between the parent and its TPs are calculated. The filter method can be used to threshold structural similarities. This may be useful under the assumption that parents and TPs who have a high structural similarity, also likely have a high MS/MS spectral similarity (which can be evaluated after componentization withgenerateComponentsTPs).fpTypeThe type of structural fingerprint that should be calculated. See thetypeargument of theget.fingerprintfunction of rcdk.fpSimMethodThe method for calculating similarities (i.e. not dissimilarity!). See themethodargument of thefp.sim.matrixfunction of the fingerprint package.
These parameters are passed as a named list as the TPStructParams argument to functions.
The getDefTPStructParams function generates such parameter list with defaults.
References
Guha R (2007).
“Chemical Informatics Functionality in R.”
Journal of Statistical Software, 18(6).
OBoyle NM, Banck M, James CA, Morley C, Vandermeersch T, Hutchison GR (2011).
“Open Babel: An open chemical toolbox.”
Journal of Cheminformatics, 3(1).
doi:10.1186/1758-2946-3-33
.