Obtains extracted ion chromatograms (EICs)
Source:R/main.R, R/features.R, R/feature_groups.R, and 1 more
getEICs-methods.RdThese methods generate one or more EIC(s). The data.table and data.frame methods generate EIC(s) for
given retention time, m/z and optionally mobility ranges. The features and featureGroups
methods generate EICs for all (or selected) features and feature groups, respectively, whereby the ranges are
automatically determined from the feature data (see the EIC parameters for configuration
options).
Usage
# S4 method for class 'features'
getEICs(
obj,
analysis = analyses(obj),
EICParams = getDefEICParams(),
output = "fill"
)
# S4 method for class 'featureGroups'
getEICs(
obj,
analysis = analyses(obj),
groupName = names(obj),
EICParams = getDefEICParams(),
output = "fill"
)
# S4 method for class 'data.table'
getEICs(obj, ranges, gapFactor = 3, output = "fill", minIntensityIMS = 25)
# S4 method for class 'data.frame'
getEICs(obj, ...)Arguments
- obj
For the
data.tableanddata.framemethods: a table with analysis information. For thefeaturesandfeatureGroupsmethods: the object for which EICs should be generated.- analysis
A
charactervector with the analyses for which EICs should be generated.- EICParams
A named
listwith parameters used for extracted ion chromatogram (EIC) creation. See the EIC parameters documentation for more details.- output
Should be
"fill","pad"or"raw". Internally, EIC data is compressed by omitting any zero intensity data points. Ifoutput="fill"then the zero intensity points are re-added to obtain continuous chromatograms. Ifoutput="pad"then zero intensity points are only re-added that surround others, which is sufficient for e.g. plotting. Ifoutput="raw"then the original compressed data is returned.- groupName
A
charactervector with the names of the feature groups for which EICs should be generated.- ranges
A
listwith for each analysis adata.framewithnumericcolumns"retmin","retmax","mzmin","mzmax"with the lower/upper ranges of the retention time and m/z. Furthermore, columns"mobmin"and"mobmax"can be added for mobility lower/upper ranges in IMS data.- gapFactor
A
numericthat configures gap filling. SeegetDefEICParamsfor more details.- minIntensityIMS
(IMS workflow) Raw intensity threshold for IMS data. This is primarily intended to speed up raw data processing.
- ...
For the
data.framemethod: further arguments passed to thedata.tablemethod.
Value
A list with for each analysis a list with EIC data. For the data.table and
data.frame methods the EICs are ordered according to the rows in ranges. For the features and
featureGroups methods the EICs are named after the feature IDs and feature group names, respectively, and
analyses without any EIC data are omitted.
If output="raw" then additional columns with e.g. mean-averaged and base peak m/z values for
each data point are returned. Furthermore, the allXValues attribute is set that can be used to obtain the
original retention time values to reconstruct the original complete chromatogram.
Functions
getEICs(features): Generates EICs for all (or selected) features (method forfeatures).getEICs(featureGroups): Generates EICs for all (or selected) feature groups (method forfeatureGroups).getEICs(data.table): Generates one or more EIC(s) for given retention time, m/z and optionally mobility ranges (method fordata.table).getEICs(data.frame): Wrapper for thedata.tablemethod (method fordata.frame).
Use of raw HRMS data
The raw data interface of patRoon is used by getEICs to
process HRMS (or IMS-HRMS) data. Please see its documentation for more information on the supported
formats and available configuration options.