Fold change calculation
Details
Fold change calculation can be used to easily identify significant changes between replicates. The
calculation process is configured through a parameter list, which can be constructed with the getFCParams
function. The parameter list has the following entries:
replicatesthe name of the two replicates to compare (taken from thereplicatesargument togetFCParams).thresholdFC: the threshold log FC for a feature group to be classified as increasing/decreasing.thresholdPV: the threshold log P for a feature group to be significantly different.zeroMethod,zeroValue: how to handle zero values when calculating the FC:addadds an offset to zero values,"fixed"sets zero values to a fixed number and"omit"removes zero data. The number that is added/set by the former two options is defined byzeroValue.PVTestFunc: a function that is used to calculate P values (usually usingt.test).PVAdjFunc: a function that is used to adjust P values (usually usingp.adjust)