Parameters that define how mobility or CCS values between e.g. features and suspects should be matched.
Details
The following parameters should be defined:
paramShould be"mobility"or"CCS"to match by mobility or CCS, respectively.window,relativeThewindowparameter sets the tolerance window size used for matching. Ifrelative=TRUEthen the tolerance is relative (0-1). The defaults forwindoware (see limits):defaultLim("mobility", "medium")(param="mobility"andrelative=FALSE)defaultLim("mobility", "medium_rel")(param="mobility"andrelative=TRUE)defaultLim("CCS", "medium")(param="CCS"andrelative=FALSE)defaultLim("CCS", "medium_rel")(param="CCS"andrelative=TRUE)
minMatchesThe minimum number of mobility/CCS matches for a suspect hit. If the number of available reference mobility/CCS values in the suspect list is less thanminMatches, then that number is used as threshold. Set to0to disable.
These parameters are passed as a named list as the IMSMatchParams argument to functions.
The getIMSMatchParams function generates such parameter list with defaults.