Group features using XCMS (old interface)
Source:R/generics.R, R/feature_groups-xcms.R
groupFeaturesXCMS.RdGroup and align features with the legacy xcmsSet function from the xcms package.
Usage
groupFeaturesXCMS(feat, ...)
# S4 method for class 'features'
groupFeaturesXCMS(
feat,
rtalign = TRUE,
loadRawData = TRUE,
groupArgs = list(mzwid = 0.015),
retcorArgs = list(method = "obiwarp"),
verbose = TRUE
)
# S4 method for class 'featuresSet'
groupFeaturesXCMS(feat, groupArgs = list(mzwid = 0.015), verbose = TRUE)Arguments
- feat
The
featuresobject with the features to be grouped.- ...
Further parameters passed to the selected grouping algorithm.
- rtalign
Set to
TRUEto enable retention time alignment.- loadRawData
Set to
TRUEif analyses are available asmzXMLormzMLfiles. Otherwise MS data is not loaded, and some dummy data (e.g. file paths) is used in the returned object.- groupArgs
named
character vectorthat may contain extra grouping parameters to be used byxcms::group- retcorArgs
named
character vectorthat may contain extra parameters to be used byxcms::retcor.- verbose
if
FALSEthen no text output will be shown.
Value
An object of a class which is derived from featureGroups.
Details
This function uses XCMS to group features. This function is called when calling groupFeatures with
algorithm="xcms".
Grouping of features and
alignment of their retention times are performed with the xcms::group and
xcms::retcor functions, respectively. Both functions have an extensive list of
parameters to modify their behavior and may therefore be used to potentially optimize results.
Sets workflows
loadRawData and arguments related to retention time alignment are currently not
supported for sets workflows.
References
Benton HP, Want EJ, Ebbels TMD (2010).
“Correction of mass calibration gaps in liquid chromatography-mass spectrometry metabolomics data.”
BIOINFORMATICS, 26, 2488.
Louail P, Brunius C, Garcia-Aloy M, Kumler W, Storz N, Stanstrup J, Treutler H, Vangeenderhuysen P, Witting M, Neumann S, Rainer J (2025).
“xcms in Peak Form: Now Anchoring a Complete Metabolomics Data Preprocessing and Analysis Software Ecosystem.”
Analytical Chemistry.
doi:10.1021/acs.analchem.5c04338
.
https://doi.org/10.1021/acs.analchem.5c04338.
Smith, C.A., Want, E.J., O'Maille, G., Abagyan,R., Siuzdak, G. (2006).
“XCMS: Processing mass spectrometry data for metabolite profiling using nonlinear peak alignment, matching and identification.”
Analytical Chemistry, 78, 779–787.
Tautenhahn R, Boettcher C, Neumann S (2008).
“Highly sensitive feature detection for high resolution LC/MS.”
BMC Bioinformatics, 9, 504.
See also
groupFeatures for more details and other algorithms.