Imports feature groups from enviMass
Source:R/feature_groups-envimass.R
importFeatureGroupsEnviMass.RdImports a 'profiles' produced by enviMass.
Arguments
- input
The path of the enviMass project.
- feat
The
featuresobject obtained withimportFeaturesEnviMass.- positive
Whether data from positive (
TRUE) or negative (FALSE) should be loaded.
Value
An object of a class which is derived from featureGroups.
Details
This function imports data from enviMass. This function is called when calling importFeatureGroups with
type="envimass".
This function only imports 'raw' profiles, not any results from further componentization steps
performed in enviMass. Furthermore, this functionality has only been tested with older versions of
enviMass. Finally, please note that this function only supports features imported by
importFeaturesEnviMass (obviously, the same project should be used for both importing functions).
See also
importFeatureGroups for more details and other algorithms.