Imports feature groups from KPIC2

importFeatureGroupsKPIC2(input, analysisInfo)

Arguments

input

A grouped PIC set object (e.g. as returned by KPIC::PICset.group).

analysisInfo

A data.frame (or data.table) with Analysis information.

Value

An object of a class which is derived from featureGroups.

Details

This function imports data from KPIC2. This function is called when calling importFeatureGroups with type="kpic2".

References

Ji H, Zeng F, Xu Y, Lu H, Zhang Z (2017). “KPIC2: An Effective Framework for Mass Spectrometry-Based Metabolomics Using Pure Ion Chromatograms.” Analytical Chemistry, 89(14), 7631–7640. doi:10.1021/acs.analchem.7b01547 .

See also

importFeatureGroups for more details and other algorithms.

groupFeatures