Imports feature groups from KPIC2
importFeatureGroupsKPIC2(input, analysisInfo)A grouped PIC set object (e.g. as returned by
KPIC::PICset.group).
A data.frame (or data.table) with Analysis
information.
An object of a class which is derived from featureGroups.
This function imports data from KPIC2. This function is called when calling importFeatureGroups with
type="kpic2".
Ji H, Zeng F, Xu Y, Lu H, Zhang Z (2017). “KPIC2: An Effective Framework for Mass Spectrometry-Based Metabolomics Using Pure Ion Chromatograms.” Analytical Chemistry, 89(14), 7631–7640. doi:10.1021/acs.analchem.7b01547 .
importFeatureGroups for more details and other algorithms.