Generic function to import features produced by other software.
Value
An object of a class which is derived from features.
Details
importFeatures is a generic function that will import features by one of the supported algorithms. The actual
functionality is provided by algorithm specific functions such as importFeaturesXCMS3 and importFeaturesTable. While these
functions may be called directly, importFeatures provides a generic interface and is therefore usually preferred.
See also
The features output class and its methods and the algorithm specific functions:
importFeaturesXCMS, importFeaturesXCMS3, importFeaturesKPIC2, importFeaturesTable, importFeaturesEnviMass
findFeatures to find new features.