Imports features from a project generated by the enviMass package.
importFeaturesEnviMass(input, analysisInfo)The path of the enviMass project.
A data.frame (or data.table) with Analysis
information.
An object of a class which is derived from features.
This function imports data from enviMass. This function is called when calling importFeatures with
type="envimass".
This functionality has only been tested with older versions of enviMass.
importFeatures for more details and other algorithms.