Automatically installs the C3SDB Python package

installC3SDB(envname = "patRoon-C3SDB", clearEnv = FALSE, ...)

Arguments

envname

The name of the virtual Python environment to install C3SDB into. Passed to reticulate::py_install. Set to NULL to not set any virtual Python environment.

clearEnv

Set to TRUE to remove the virtual environment if it already exists (using reticulate::virtualenv_remove). Ignored if envname is NULL.

...

Further arguments passed to reticulate::py_install.

Details

This function uses reticulate to install the C3SDB Python package in a virtual environment.

References

Ross DH, Cho JH, Xu L (2020). “Breaking Down Structural Diversity for Comprehensive Prediction of Ion-Neutral Collision Cross Sections.” Analytical Chemistry, 92(6), 4548–4557. ISSN 1520-6882, doi:10.1021/acs.analchem.9b05772 , http://dx.doi.org/10.1021/acs.analchem.9b05772.