Automatically installs the TIMSCONVERT Python package

installTIMSCONVERT(envname = "patRoon-TIMSCONVERT", clearEnv = FALSE, ...)

Arguments

envname

The name of the virtual Python environment to install TIMSCONVERT into. Passed to reticulate::py_install. Set to NULL to not set any virtual Python environment.

clearEnv

Set to TRUE to remove the virtual environment if it already exists (using reticulate::virtualenv_remove). Ignored if envname is NULL.

...

Further arguments passed to reticulate::py_install.

Details

This function uses reticulate to install the TIMSCONVERT Python package in a virtual environment.

References

Luu GT, Freitas MA, Lizama-Chamu I, McCaughey CS, Sanchez LM, Wang M (2022). “TIMSCONVERT: a workflow to convert trapped ion mobility data to open data formats.” Bioinformatics, 38(16), 4046–4047. ISSN 1367-4811, doi:10.1093/bioinformatics/btac419 , http://dx.doi.org/10.1093/bioinformatics/btac419.