Launches a Shiny app for generating and plotting EICs and EIMs.
# S4 method for class 'data.frame'
launchEICGUI(obj, suspects = NULL, adduct = NULL)
# S4 method for class 'features'
launchEICGUI(obj)
# S4 method for class 'featureGroups'
launchEICGUI(obj)A Shiny app object.
These tools were originally developed as internal tools to debug and explore IMS related algorithms. They were mostly generated with LLMs, hence, may contain nonsense and bugs. Nevertheless, they may be useful for users to explore EICs and EIMs interactively. Please use with caution and report any issues.