Workflow solutions for mass-spectrometry based non-target analysis.
Source:R/main.R
patRoon-package.RdProvides an easy-to-use interface to a mass spectrometry based non-target analysis workflow. Various (open-source) tools are combined which provide algorithms for extraction and grouping of features, extraction of MS and MS/MS data, automatic formula and compound annotation and grouping related features to components. In addition, various tools are provided for e.g. data preparation and cleanup, plotting results and automatic reporting.
Package options
The following package options (see options) can be set:
patRoon.cache.mode: Acharactersetting the current caching mode:"save"and"load"will only save/load results to/from the cache,"both"(default) will do both and"none"to completely disable caching. This option can be changed anytime, which might be useful, for instance, to temporarily disable cached results before running a function.patRoon.cache.fileName: acharacterspecifying the name of the cache file (default iscache.sqlite).patRoon.cache.maxEntries: anumericspecifying the maximum number of entries per cache category (default is 100000). When this limit is exceeded, the oldest entries are automatically removed.patRoon.MS.backends,patRoon.MS.preferIMS,patRoon.path.TDFSDK: Options related to the raw data interface.patRoon.threads: The number of threads to be used for parallelization. This is currently only used by the raw data interface and when thepiekalgorithm is used for peak detection.patRoon.MP.maxProcs: The maximum number of processes that should be initiated in parallel. A good starting point is the number of physical cores, which is the default as detected bydetectCores. This option is only used when patRoon.MP.method="classic".patRoon.MP.method: Either"classic"or"future". The former is the default and uses processx to execute multiple commands in parallel. When"future"thefuture.applypackage is used for parallelization, which is especially useful for e.g. cluster computing.patRoon.MP.futureSched: Sets thefuture.schedulingfunction argument forfuture_lapply. Only used if patRoon.MP.method="future".patRoon.MP.logPath: The path used for logging of output from commands executed by multiprocess. Set toFALSEto disable logging.patRoon.path.pwiz: The path in which theProteoWizardbinaries are installed. If unset an attempt is made to find this directory from the Windows registry and PATH environment variable.patRoon.path.GenForm: The path to theGenFormexecutable. If not set (the default) the internalGenFormbinary is used. Only set if you want to override the executable.patRoon.path.MetFragCL: The complete file path to the MetFrag CLjarto be used bygenerateCompoundsMetFrag. Example:"C:/MetFrag2.4.2-CL.jar".patRoon.path.MetFragCompTox: The complete file path to the CompTox databasecsvfile. SeegenerateCompoundsfor more details.patRoon.path.MetFragPubChemLite: The complete file path to the PubChemLite databasecsvfile. SeegenerateCompoundsfor more details.patRoon.path.SIRIUS: The directory in which the SIRIUS binaries are installed. Used by all functions that interface withSIRIUS, such asgenerateFormulasSIRIUSandgenerateCompoundsSIRIUS. Example:"C:/sirius-win64-3.5.1". Note that the location of the binaries differs for each operating system.patRoon.path.OpenMS: The path in which theOpenMSbinaries are installed.patRoon.path.obabel: The path in which theOpenBabelbinaries are installed.patRoon.path.BiotransFormerThe full file path to thebiotransformer.jarcommand line utility. This needs to be set whengenerateTPsBioTransformeris used. For more details see https://bitbucket.org/djoumbou/biotransformer/src/master.patRoon.path.limitsA path to a customized limits YAML file.
Most external dependencies are provided by patRoonExt or otherwise found in the system environment
PATH variable. However, the patRoon.path.* options should be set if this fails or you want to
override the location. The verifyDependencies function can be used to assess if dependencies are
found.
Author
Maintainer: Rick Helmus r.helmus@uva.nl (ORCID)
Authors:
Rick Helmus r.helmus@uva.nl (ORCID)
Other contributors: