Parameters relevant for calculation of similarities between mass spectra.
Details
For the calculation of spectral similarities the following parameters exist:
methodThe similarity method: either"cosine"or"jaccard".removePrecursorIfTRUEthen precursor peaks (i.e. the mass peak corresponding to the feature) are removed prior to similarity calculation.mzWeight,intWeightMass and intensity weights used for cosine calculation.absMzDevMaximum absolute m/z deviation between mass peaks, used for binning spectra. Defaults todefaultLim("mz", "medium")(see limits).relMinIntensityThe minimum relative intensity for mass peaks (0-1). Peaks with lower intensities are not considered for similarity calculation. The relative intensities are called after the precursor peak is removed whenremovePrecursor=TRUE.minPeaksOnly consider spectra that have at least this amount of peaks (after the spectrum is filtered).shiftIf and how shifting is applied prior to similarity calculation. Valid options are:"none"(no shifting),"precursor"(all mass peaks of the second spectrum are shifted by the mass difference between the precursors of both spectra) or"both"(the spectra are first binned without shifting, and peaks still unaligned are then shifted as is done whenshift="precursor").setCombinedMethod(sets workflow) Determines how spectral similarities from different sets are combined. Possible values are"mean","min"or"max", which calculates the combined value as the mean, minimum or maximum value, respectively.NAvalues (e.g. if a set does not have peak list data to combine) are removed in advance.
These parameters are typically passed as a named list as the specSimParams argument to functions that
do spectral similarity calculations. The getDefSpecSimParams function can be used to generate such parameter
list with defaults.