All workflow objects (e.g. featureGroups,
compounds, etc) are derived from this class. Objects from this
class are never created directly.
Usage
# S4 method for class 'workflowStep'
algorithm(obj)
# S4 method for class 'workflowStep'
as.data.table(x, keep.rownames = FALSE, ...)
# S4 method for class 'workflowStep'
as.data.frame(x, row.names = NULL, optional = FALSE, ...)
# S4 method for class 'workflowStep'
show(object)Methods (by generic)
algorithm(workflowStep): Returns the algorithm that was used to generate an object.as.data.table(workflowStep): Summarizes the data in this object and returns this as adata.table.as.data.frame(workflowStep): This method simply callsas.data.tableand converts the result to a classic adata.frame.show(workflowStep): Shows summary information for this object.
Slots
algorithmThe algorithm that was used to generate this object. Use the
algorithmmethod for access.